@@ -1,5 +1,5 @@
 /* arm_table.h --
- * Copyright 2009-10,2013-21 Red Hat Inc.
+ * Copyright 2009-10,2013-24 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -432,4 +432,14 @@ _S(448, "process_mrelease")
 _S(449, "futex_waitv")
 _S(450, "set_mempolicy_home_node")
 _S(451, "cachestat")
+_S(452, "fchmodat2")
+_S(453, "map_shadow_stack")
+_S(454, "futex_wake")
+_S(455, "futex_wait")
+_S(456, "futex_requeue")
+_S(457, "statmount")
+_S(458, "listmount")
+_S(459, "lsm_get_self_attr")
+_S(460, "lsm_set_self_attr")
+_S(461, "lsm_list_modules")
 
